@@ -8,7 +8,7 @@ Some key differences:
 - pydantic dataclasses instead of vanilla dataclasses,
   see https://pydantic-docs.helpmanual.io/usage/dataclasses/
 
-- PredicateType is replaced by a Predicate enum
+- PredicateType type is replaced by a PredicateType enum
 
 - UriOrCurie is replaced with a Curie type as a goal to represent
   all identifiers as curies, IriType is still included in a few attributes
@@ -126,6 +126,14 @@ class PydanticGen(PythonGenerator):
             if self.schema.generation_date
             else ''
         )
+        predicates = (
+            f'''
+# Predicates
+{self.gen_predicate_enum()}
+'''
+            if self.schema.source_file == 'biolink-model.yaml'  # this is awful sorry
+            else ''
+        )
 
         return f'''{head}
 # id: {self.schema.id}
@@ -135,9 +143,10 @@ class PydanticGen(PythonGenerator):
 import datetime
 import inspect
 import logging
+from collections import namedtuple
 from enum import Enum, unique
 from dataclasses import field
-from typing import Any, ClassVar, List, Optional, Union
+from typing import Any, ClassVar, List, Optional, Union, Dict
 import re
 
 from pydantic import constr, validator
@@ -171,8 +180,7 @@ Quotient = float
 # Pydantic config and validators
 {self._get_pydantic_config_and_validators()}
 
-# Predicates
-{self.gen_predicate_enum()}
+{predicates}
 
 # Enumerations
 {self.gen_enumerations()}
@@ -374,9 +382,7 @@ Quotient = float
         """
         base = rangelist[0].split('.')[-1]
 
-        if slot_name == 'predicate':
-            class_ref = "Predicate"
-        elif slot_name in [
+        if slot_name in [
             'id',
             'category',
             'provided_by',
@@ -536,12 +542,17 @@ class {enum_name}(str, Enum):
         formatted_predicates = '\n'.join([f'    {pred} = "biolink:{pred}"' for pred in predicates])
 
         return f'''
-class Predicate(str, Enum):
+@unique
+class PredicateType(str, Enum):
     """
     Enum for biolink predicates
     """
 
 {formatted_predicates}
+
+Predicate = namedtuple(
+    'biolink_predicate', [pred.value.replace('biolink:', '') for pred in PredicateType]
+)(*[pred.value for pred in PredicateType])
 '''.strip()
 
     def gen_pydantic_validators(self, cls) -> str:
